diff -pruN 2.13.3-1/BUILD.bazel 2.13.4-2/BUILD.bazel
--- 2.13.3-1/BUILD.bazel	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/BUILD.bazel	2020-12-29 14:03:40.000000000 +0000
@@ -3,8 +3,15 @@ load("@rules_cc//cc:defs.bzl", "cc_libra
 
 # Header-only rule to export catch2/catch.hpp.
 cc_library(
-  name = "catch2",
-  hdrs = ["single_include/catch2/catch.hpp"],
-  visibility = ["//visibility:public"],
-  includes = ["single_include/"],
+    name = "catch2",
+    hdrs = ["single_include/catch2/catch.hpp"],
+    includes = ["single_include/"],
+    visibility = ["//visibility:public"],
+)
+
+cc_library(
+    name = "catch2_with_main",
+    srcs = ["src/catch_with_main.cpp"],
+    visibility = ["//visibility:public"],
+    deps = ["//:catch2"],
 )
diff -pruN 2.13.3-1/CMakeLists.txt 2.13.4-2/CMakeLists.txt
--- 2.13.3-1/CMakeLists.txt	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/CMakeLists.txt	2020-12-29 14:03:40.000000000 +0000
@@ -14,7 +14,7 @@ if (CMAKE_BINARY_DIR STREQUAL CMAKE_CURR
 endif()
 
 
-project(Catch2 LANGUAGES CXX VERSION 2.13.3)
+project(Catch2 LANGUAGES CXX VERSION 2.13.4)
 
 # Provide path for scripts
 list(APPEND CMAKE_MODULE_PATH "${CMAKE_CURRENT_LIST_DIR}/CMake")
@@ -103,6 +103,12 @@ endif()
 # provide a namespaced alias for clients to 'link' against if catch is included as a sub-project
 add_library(Catch2::Catch2 ALIAS Catch2)
 
+# Hacky support for compiling the impl into a static lib
+add_library(Catch2WithMain ${CMAKE_CURRENT_LIST_DIR}/src/catch_with_main.cpp)
+target_link_libraries(Catch2WithMain PUBLIC Catch2)
+add_library(Catch2::Catch2WithMain ALIAS Catch2WithMain)
+
+
 # Only perform the installation steps when Catch is not being used as
 # a subproject via `add_subdirectory`, or the destinations will break,
 # see https://github.com/catchorg/Catch2/issues/1373
@@ -121,7 +127,7 @@ if (NOT_SUBPROJECT)
     # create and install an export set for catch target as Catch2::Catch
     install(
       TARGETS
-        Catch2
+        Catch2 Catch2WithMain
       EXPORT
         Catch2Targets
       DESTINATION
diff -pruN 2.13.3-1/conanfile.py 2.13.4-2/conanfile.py
--- 2.13.3-1/conanfile.py	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/conanfile.py	2020-12-29 14:03:40.000000000 +0000
@@ -10,7 +10,7 @@ class CatchConan(ConanFile):
     homepage = url
     license = "BSL-1.0"
     exports = "LICENSE.txt"
-    exports_sources = ("single_include/*", "CMakeLists.txt", "CMake/*", "contrib/*")
+    exports_sources = ("single_include/*", "CMakeLists.txt", "CMake/*", "contrib/*", "src/*")
     generators = "cmake"
 
     def package(self):
diff -pruN 2.13.3-1/contrib/Catch.cmake 2.13.4-2/contrib/Catch.cmake
--- 2.13.3-1/contrib/Catch.cmake	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/contrib/Catch.cmake	2020-12-29 14:03:40.000000000 +0000
@@ -202,4 +202,5 @@ endfunction()
 
 set(_CATCH_DISCOVER_TESTS_SCRIPT
   ${CMAKE_CURRENT_LIST_DIR}/CatchAddTests.cmake
+  CACHE INTERNAL "Catch2 full path to CatchAddTests.cmake helper file"
 )
diff -pruN 2.13.3-1/contrib/ParseAndAddCatchTests.cmake 2.13.4-2/contrib/ParseAndAddCatchTests.cmake
--- 2.13.3-1/contrib/ParseAndAddCatchTests.cmake	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/contrib/ParseAndAddCatchTests.cmake	2020-12-29 14:03:40.000000000 +0000
@@ -241,6 +241,7 @@ endfunction()
 
 # entry point
 function(ParseAndAddCatchTests TestTarget)
+    message(DEPRECATION "ParseAndAddCatchTest: function deprecated because of possibility of missed test cases. Consider using 'catch_discover_tests' from 'Catch.cmake'")
     ParseAndAddCatchTests_PrintDebugMessage("Started parsing ${TestTarget}")
     get_target_property(SourceFiles ${TestTarget} SOURCES)
     ParseAndAddCatchTests_PrintDebugMessage("Found the following sources: ${SourceFiles}")
diff -pruN 2.13.3-1/debian/changelog 2.13.4-2/debian/changelog
--- 2.13.3-1/debian/changelog	2020-11-01 21:39:18.000000000 +0000
+++ 2.13.4-2/debian/changelog	2021-01-11 21:27:33.000000000 +0000
@@ -1,3 +1,18 @@
+catch2 (2.13.4-2) unstable; urgency=medium
+
+  * Merge the libcatch2-dev package into catch2
+
+ -- Mathieu Mirmont <mat@parad0x.org>  Mon, 11 Jan 2021 22:27:33 +0100
+
+catch2 (2.13.4-1) unstable; urgency=medium
+
+  * New upstream release
+  * Provide Catch2WithMain as libcatch2-dev package
+  * patches: make the build reproducible
+  * control: bump policy to 4.5.1, no change required
+
+ -- Mathieu Mirmont <mat@parad0x.org>  Tue, 29 Dec 2020 21:12:46 +0100
+
 catch2 (2.13.3-1) unstable; urgency=medium
 
   * New upstream release
diff -pruN 2.13.3-1/debian/control 2.13.4-2/debian/control
--- 2.13.3-1/debian/control	2020-11-01 21:39:18.000000000 +0000
+++ 2.13.4-2/debian/control	2021-01-11 21:27:33.000000000 +0000
@@ -3,14 +3,14 @@ Section: devel
 Priority: optional
 Maintainer: Mathieu Mirmont <mat@parad0x.org>
 Build-Depends: cmake, debhelper-compat (= 13), python3
-Standards-Version: 4.5.0
+Standards-Version: 4.5.1
 Homepage: https://github.com/catchorg/Catch2
 Vcs-Browser: https://salsa.debian.org/debian/catch2
 Vcs-Git: https://salsa.debian.org/debian/catch2.git
 Rules-Requires-Root: no
 
 Package: catch2
-Architecture: all
+Architecture: any
 Depends: ${misc:Depends}
 Multi-Arch: foreign
 Description: C++ Automated Test Cases in Headers
diff -pruN 2.13.3-1/debian/gitlab-ci.yml 2.13.4-2/debian/gitlab-ci.yml
--- 2.13.3-1/debian/gitlab-ci.yml	2020-04-11 17:56:53.000000000 +0000
+++ 2.13.4-2/debian/gitlab-ci.yml	2020-12-30 22:50:41.000000000 +0000
@@ -4,11 +4,3 @@
 include:
   - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/salsa-ci.yml
   - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/pipeline-jobs.yml
-
-##
-## Disable some jobs that don't make much sense here.
-##
-variables:
-  SALSA_CI_DISABLE_BLHC: '1'
-  SALSA_CI_DISABLE_BUILD_PACKAGE_ANY: '1'
-  SALSA_CI_LINTIAN_SUPPRESS_TAGS: 'field-too-long'
diff -pruN 2.13.3-1/debian/patches/0001-Make-the-build-reproducible-on-g-version-8.patch 2.13.4-2/debian/patches/0001-Make-the-build-reproducible-on-g-version-8.patch
--- 2.13.3-1/debian/patches/0001-Make-the-build-reproducible-on-g-version-8.patch	1970-01-01 00:00:00.000000000 +0000
+++ 2.13.4-2/debian/patches/0001-Make-the-build-reproducible-on-g-version-8.patch	2020-12-31 13:23:59.000000000 +0000
@@ -0,0 +1,29 @@
+From: Mathieu Mirmont <mat@parad0x.org>
+Date: Tue, 29 Dec 2020 21:00:09 +0100
+Subject: Make the build reproducible on g++ version 8+
+
+Make the build reproducible by removing references to the source
+directory from the Catch2WithMain static library.
+
+Forwarded: https://github.com/catchorg/Catch2/pull/2141
+---
+ CMakeLists.txt | 6 ++++++
+ 1 file changed, 6 insertions(+)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 4d57dd1..4ef1d9d 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -108,6 +108,12 @@ add_library(Catch2WithMain ${CMAKE_CURRENT_LIST_DIR}/src/catch_with_main.cpp)
+ target_link_libraries(Catch2WithMain PUBLIC Catch2)
+ add_library(Catch2::Catch2WithMain ALIAS Catch2WithMain)
+ 
++# Make the build reproducible on versions of g++ that supports -ffile-prefix-map
++if("${CMAKE_CXX_COMPILER_ID}" STREQUAL "GNU")
++  if(NOT CMAKE_CXX_COMPILER_VERSION VERSION_LESS 8)
++    target_compile_options(Catch2WithMain PRIVATE "-ffile-prefix-map=${CMAKE_SOURCE_DIR}=.")
++  endif()
++endif()
+ 
+ # Only perform the installation steps when Catch is not being used as
+ # a subproject via `add_subdirectory`, or the destinations will break,
diff -pruN 2.13.3-1/debian/patches/series 2.13.4-2/debian/patches/series
--- 2.13.3-1/debian/patches/series	1970-01-01 00:00:00.000000000 +0000
+++ 2.13.4-2/debian/patches/series	2020-12-31 13:23:59.000000000 +0000
@@ -0,0 +1 @@
+0001-Make-the-build-reproducible-on-g-version-8.patch
diff -pruN 2.13.3-1/docs/cmake-integration.md 2.13.4-2/docs/cmake-integration.md
--- 2.13.3-1/docs/cmake-integration.md	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/docs/cmake-integration.md	2020-12-29 14:03:40.000000000 +0000
@@ -57,7 +57,7 @@ with automatically registering their `TE
 can be found in the `contrib` folder, and are
 
 1) `Catch.cmake` (and its dependency `CatchAddTests.cmake`)
-2) `ParseAndAddCatchTests.cmake`
+2) `ParseAndAddCatchTests.cmake` (deprecated)
 
 If Catch2 has been installed in system, both of these can be used after
 doing `find_package(Catch2 REQUIRED)`. Otherwise you need to add them
@@ -176,10 +176,17 @@ the output file name e.g. ".xml".
 
 ### `ParseAndAddCatchTests.cmake`
 
+⚠ This script is [deprecated](https://github.com/catchorg/Catch2/pull/2120)
+in Catch 2.13.4 and superseded by the above approach using `catch_discover_tests`.
+See [#2092](https://github.com/catchorg/Catch2/issues/2092) for details.
+
 `ParseAndAddCatchTests` works by parsing all implementation files
 associated with the provided target, and registering them via CTest's
 `add_test`. This approach has some limitations, such as the fact that
-commented-out tests will be registered anyway.
+commented-out tests will be registered anyway. More serious, only a
+subset of the assertion macros currently available in Catch can be
+detected by this script and tests with any macros that cannot be
+parsed are *silently ignored*.
 
 
 #### Usage
diff -pruN 2.13.3-1/docs/deprecations.md 2.13.4-2/docs/deprecations.md
--- 2.13.3-1/docs/deprecations.md	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/docs/deprecations.md	2020-12-29 14:03:40.000000000 +0000
@@ -72,6 +72,13 @@ Instead you will have to write this:
             REQUIRE_THAT(foo(), m1 || m2 || m3);
 ```
 
+### `ParseAndAddCatchTests.cmake`
+
+The CMake/CTest integration using `ParseAndAddCatchTests.cmake` is deprecated,
+as it can be replaced by `Catch.cmake` that provides the function
+`catch_discover_tests` to get tests directly from a CMake target via the
+command line interface instead of parsing C++ code with regular expressions.
+
 
 ## Planned changes
 
diff -pruN 2.13.3-1/docs/release-notes.md 2.13.4-2/docs/release-notes.md
--- 2.13.3-1/docs/release-notes.md	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/docs/release-notes.md	2020-12-29 14:03:40.000000000 +0000
@@ -2,6 +2,7 @@
 
 # Release notes
 **Contents**<br>
+[2.13.4](#2134)<br>
 [2.13.3](#2133)<br>
 [2.13.2](#2132)<br>
 [2.13.1](#2131)<br>
@@ -44,6 +45,22 @@
 [Even Older versions](#even-older-versions)<br>
 
 
+## 2.13.4
+
+### Improvements
+* Improved the hashing algorithm used for shuffling test cases (#2070)
+  * `TEST_CASE`s that differ only in the last character should be properly shuffled
+  * Note that this means that v2.13.4 gives you a different order of test cases than 2.13.3, even given the same seed.
+
+### Miscellaneous
+* Deprecated `ParseAndAddCatchTests` CMake integration (#2092)
+  * It is impossible to implement it properly for all the different test case variants Catch2 provides, and there are better options provided.
+  * Use `catch_discover_tests` instead, which uses runtime information about available tests.
+* Fixed bug in `catch_discover_tests` that would cause it to fail when used in specific project structures (#2119)
+* Added Bazel build file
+* Added an experimental static library target to CMake
+
+
 ## 2.13.3
 
 ### Fixes
diff -pruN 2.13.3-1/docs/slow-compiles.md 2.13.4-2/docs/slow-compiles.md
--- 2.13.3-1/docs/slow-compiles.md	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/docs/slow-compiles.md	2020-12-29 14:03:40.000000000 +0000
@@ -5,6 +5,7 @@
 [Short answer](#short-answer)<br>
 [Long answer](#long-answer)<br>
 [Practical example](#practical-example)<br>
+[Using the static library Catch2WithMain](#using-the-static-library-catch2withmain)<br>
 [Other possible solutions](#other-possible-solutions)<br>
 
 Several people have reported that test code written with Catch takes much longer to compile than they would expect. Why is that?
@@ -64,6 +65,39 @@ tests-factorial.cpp:11: failed: Factoria
 Failed 1 test case, failed 1 assertion.
 ```
 
+
+## Using the static library Catch2WithMain
+
+Catch2 also provides a static library that implements the runner. Note
+that this support is experimental, due to interactions between Catch2 v2
+implementation and C++ linking limitations.
+
+As with the `Catch2` target, the `Catch2WithMain` CMake target can be used
+either from a subdirectory, or from installed build.
+
+
+### CMake
+```cmake
+add_executable(tests-factorial tests-factorial.cpp)
+
+target_link_libraries(tests-factorial Catch2::Catch2WithMain)
+```
+
+### bazel
+```python
+cc_test(
+    name = "hello_world_test",
+    srcs = [
+        "test/hello_world_test.cpp",
+    ],
+    deps = [
+        "lib_hello_world",
+        "@catch2//:catch2_with_main",
+    ],
+)
+```
+
+
 ## Other possible solutions
 You can also opt to sacrifice some features in order to speed-up Catch's compilation times. For details see the [documentation on Catch's compile-time configuration](configuration.md#other-toggles).
 
diff -pruN 2.13.3-1/include/catch.hpp 2.13.4-2/include/catch.hpp
--- 2.13.3-1/include/catch.hpp	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/include/catch.hpp	2020-12-29 14:03:40.000000000 +0000
@@ -11,7 +11,7 @@
 
 #define CATCH_VERSION_MAJOR 2
 #define CATCH_VERSION_MINOR 13
-#define CATCH_VERSION_PATCH 3
+#define CATCH_VERSION_PATCH 4
 
 #ifdef __clang__
 #    pragma clang system_header
diff -pruN 2.13.3-1/include/internal/catch_test_case_registry_impl.cpp 2.13.4-2/include/internal/catch_test_case_registry_impl.cpp
--- 2.13.3-1/include/internal/catch_test_case_registry_impl.cpp	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/include/internal/catch_test_case_registry_impl.cpp	2020-12-29 14:03:40.000000000 +0000
@@ -22,24 +22,28 @@ namespace Catch {
 
     namespace {
         struct TestHasher {
-            explicit TestHasher(Catch::SimplePcg32& rng_instance) {
-                basis = rng_instance();
-                basis <<= 32;
-                basis |= rng_instance();
-            }
+            using hash_t = uint64_t;
 
-            uint64_t basis;
+            explicit TestHasher( hash_t hashSuffix ):
+                m_hashSuffix{ hashSuffix } {}
 
-            uint64_t operator()(TestCase const& t) const {
-                // Modified FNV-1a hash
-                static constexpr uint64_t prime = 1099511628211;
-                uint64_t hash = basis;
-                for (const char c : t.name) {
+            uint32_t operator()( TestCase const& t ) const {
+                // FNV-1a hash with multiplication fold.
+                const hash_t prime = 1099511628211u;
+                hash_t hash = 14695981039346656037u;
+                for ( const char c : t.name ) {
                     hash ^= c;
                     hash *= prime;
                 }
-                return hash;
+                hash ^= m_hashSuffix;
+                hash *= prime;
+                const uint32_t low{ static_cast<uint32_t>( hash ) };
+                const uint32_t high{ static_cast<uint32_t>( hash >> 32 ) };
+                return low * high;
             }
+
+        private:
+            hash_t m_hashSuffix;
         };
     } // end unnamed namespace
 
@@ -58,9 +62,9 @@ namespace Catch {
 
             case RunTests::InRandomOrder: {
                 seedRng( config );
-                TestHasher h( rng() );
+                TestHasher h{ config.rngSeed() };
 
-                using hashedTest = std::pair<uint64_t, TestCase const*>;
+                using hashedTest = std::pair<TestHasher::hash_t, TestCase const*>;
                 std::vector<hashedTest> indexed_tests;
                 indexed_tests.reserve( unsortedTestCases.size() );
 
diff -pruN 2.13.3-1/include/internal/catch_version.cpp 2.13.4-2/include/internal/catch_version.cpp
--- 2.13.3-1/include/internal/catch_version.cpp	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/include/internal/catch_version.cpp	2020-12-29 14:03:40.000000000 +0000
@@ -37,7 +37,7 @@ namespace Catch {
     }
 
     Version const& libraryVersion() {
-        static Version version( 2, 13, 3, "", 0 );
+        static Version version( 2, 13, 4, "", 0 );
         return version;
     }
 
diff -pruN 2.13.3-1/README.md 2.13.4-2/README.md
--- 2.13.3-1/README.md	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/README.md	2020-12-29 14:03:40.000000000 +0000
@@ -9,7 +9,7 @@
 [![Join the chat in Discord: https://discord.gg/4CWS9zD](https://img.shields.io/badge/Discord-Chat!-brightgreen.svg)](https://discord.gg/4CWS9zD)
 
 
-<a href="https://github.com/catchorg/Catch2/releases/download/v2.13.3/catch.hpp">The latest version of the single header can be downloaded directly using this link</a>
+<a href="https://github.com/catchorg/Catch2/releases/download/v2.13.4/catch.hpp">The latest version of the single header can be downloaded directly using this link</a>
 
 ## Catch2 is released!
 
diff -pruN 2.13.3-1/scripts/releaseCommon.py 2.13.4-2/scripts/releaseCommon.py
--- 2.13.3-1/scripts/releaseCommon.py	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/scripts/releaseCommon.py	2020-12-29 14:03:40.000000000 +0000
@@ -129,8 +129,8 @@ def updateVersionDefine(version):
 def updateVersionPlaceholder(filename, version):
     with open(filename, 'rb') as file:
         lines = file.readlines()
-    placeholderRegex = re.compile(b' in Catch X.Y.Z')
-    replacement = ' in Catch {}.{}.{}'.format(version.majorVersion, version.minorVersion, version.patchNumber).encode('ascii')
+    placeholderRegex = re.compile(b'in Catch X.Y.Z')
+    replacement = 'in Catch {}.{}.{}'.format(version.majorVersion, version.minorVersion, version.patchNumber).encode('ascii')
     with open(filename, 'wb') as file:
         for line in lines:
             file.write(placeholderRegex.sub(replacement, line))
diff -pruN 2.13.3-1/single_include/catch2/catch.hpp 2.13.4-2/single_include/catch2/catch.hpp
--- 2.13.3-1/single_include/catch2/catch.hpp	2020-10-31 17:21:23.000000000 +0000
+++ 2.13.4-2/single_include/catch2/catch.hpp	2020-12-29 14:03:40.000000000 +0000
@@ -1,6 +1,6 @@
 /*
- *  Catch v2.13.3
- *  Generated: 2020-10-31 18:20:31.045274
+ *  Catch v2.13.4
+ *  Generated: 2020-12-29 14:48:00.116107
  *  ----------------------------------------------------------
  *  This file has been merged from multiple headers. Please don't edit it directly
  *  Copyright (c) 2020 Two Blue Cubes Ltd. All rights reserved.
@@ -15,7 +15,7 @@
 
 #define CATCH_VERSION_MAJOR 2
 #define CATCH_VERSION_MINOR 13
-#define CATCH_VERSION_PATCH 3
+#define CATCH_VERSION_PATCH 4
 
 #ifdef __clang__
 #    pragma clang system_header
@@ -14126,24 +14126,28 @@ namespace Catch {
 
     namespace {
         struct TestHasher {
-            explicit TestHasher(Catch::SimplePcg32& rng_instance) {
-                basis = rng_instance();
-                basis <<= 32;
-                basis |= rng_instance();
-            }
+            using hash_t = uint64_t;
+
+            explicit TestHasher( hash_t hashSuffix ):
+                m_hashSuffix{ hashSuffix } {}
 
-            uint64_t basis;
-
-            uint64_t operator()(TestCase const& t) const {
-                // Modified FNV-1a hash
-                static constexpr uint64_t prime = 1099511628211;
-                uint64_t hash = basis;
-                for (const char c : t.name) {
+            uint32_t operator()( TestCase const& t ) const {
+                // FNV-1a hash with multiplication fold.
+                const hash_t prime = 1099511628211u;
+                hash_t hash = 14695981039346656037u;
+                for ( const char c : t.name ) {
                     hash ^= c;
                     hash *= prime;
                 }
-                return hash;
+                hash ^= m_hashSuffix;
+                hash *= prime;
+                const uint32_t low{ static_cast<uint32_t>( hash ) };
+                const uint32_t high{ static_cast<uint32_t>( hash >> 32 ) };
+                return low * high;
             }
+
+        private:
+            hash_t m_hashSuffix;
         };
     } // end unnamed namespace
 
@@ -14161,9 +14165,9 @@ namespace Catch {
 
             case RunTests::InRandomOrder: {
                 seedRng( config );
-                TestHasher h( rng() );
+                TestHasher h{ config.rngSeed() };
 
-                using hashedTest = std::pair<uint64_t, TestCase const*>;
+                using hashedTest = std::pair<TestHasher::hash_t, TestCase const*>;
                 std::vector<hashedTest> indexed_tests;
                 indexed_tests.reserve( unsortedTestCases.size() );
 
@@ -15316,7 +15320,7 @@ namespace Catch {
     }
 
     Version const& libraryVersion() {
-        static Version version( 2, 13, 3, "", 0 );
+        static Version version( 2, 13, 4, "", 0 );
         return version;
     }
 
diff -pruN 2.13.3-1/src/catch_with_main.cpp 2.13.4-2/src/catch_with_main.cpp
--- 2.13.3-1/src/catch_with_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 2.13.4-2/src/catch_with_main.cpp	2020-12-29 14:03:40.000000000 +0000
@@ -0,0 +1,2 @@
+#define CATCH_CONFIG_MAIN
+#include <catch2/catch.hpp>
